ps2afp Command


Purpose

   Transforms a PostScript Level 1 data stream file to an AFP data stream file.


Syntax

       ps2afp [-aOutputtype] [-c] [-CConfigurationfile] [-FFontmapfile]
       [-jnnnn] [-lnnnn.nnnu] [-Mnnnnn] [-oOutputfile] [-pnnn-nnn]
       [-Pnnnnn] [-q] [-rnnn] [-SServername] [-snnnn] [-Vnn]
       [-wnnnn.nnnu] [-xnnnn.nnnu] [-ynnnn.nnnu] [Inputfiles]


Description

   The ps2afp command transforms a PostScript data stream file into an AFP 
   data stream file.

   If you specify multiple values for the same flag, ps2afp uses the
   last value specified, with the exception of the -F flag and the -p flag.
   ps2afp concatenates multiple values of the -F flag from left-to-right
   (first entered to last entered).
 
   When using the ps2afp command, you can specify an optional input file
   name.  If you do not specify an input file name, ps2afp uses
   standard input.  The output file name is also optional; if you do not
   specify one, the ps2afp command writes the results to standard output.
 
   Note the following about the flags you can specify with the ps2afp
   command:
 
   1.  Flags can appear anywhere on the command line, with or without a
       blank in the flag-value pair.  Separate the flags of the ps2afp
       command with blanks; for example:
 
           ps2afp Inputfile1 Inputfile2 -o myoutput.file -l 4i -w8m
 
   2.  When you specify flags with the ps2afp command, ps2afp echoes 
       them back to your display along with the settings for the flags.
       To suppress command echoing, enter the -q (quiet) flag along with
       the ps2afp command.
 
   3.  Finally, be aware that the PostScript file may contain the
       commands letter and legal.  If these commands are present in the
       PostScript file, you may not get what you expect due to the
       interaction of the letter and legal commands with the -l and -w
       flags of the ps2afp command.  The order in which ps2afp uses
       PostScript parameters is as follows:
 
       a.  The PostScript program commands letter and legal, if they are
           present, take precedence over any other items in this list.
 
       b.  The parameters you specify on the command line with the ps2afp
           command (for example, -r300).
 
       c.  The customized configuration file you specify with the -C flag
           with the ps2afp command.
 
       d.  The configuration file ps2afp.cfg in the current directory.
 
       e.  The .ps2afp.cfg file in the $HOME directory.
 
       f.  The default ps2afp command configuration file,
           /usr/lpp/psf/ps2afp/ps2afp.cfg.
 
       g.  The default ps2afpd daemon configuration file,
           /usr/lpp/psf/ps2afp/ps2afpd.cfg.
 
       h.  The defaults accessed when you start the ps2afpd daemon.
 
 
Flags and Values
 
   -a [ IO1_G4 | IM1 | IO1 | IO1_MMR |
        PSEG_IO1_G4 | PSEG_IM1 | PSEG_IO1 | PSEG_IO1_MMR |
        OVLY_IO1_G4 | OVLY_IM1 | OVLY_IO1 | OVLY_IO1_MMR ]

                     Determines the type of AFP data stream image to
                     generate for each page in the PostScript file.
                     Values are:
 
                     IO1_G4    Compressed Image Object Content
                               Architecture (IOCA) image in Modified
                               CCITT (International Telegraph and
                               Telephone Consultative Committee) T.6 G4
                               Facsimile Coding Scheme (G4 MMR) format.
                               This is the recommended output type
                               because it takes up less space on the
                               fixed disk, and it prints faster.
 
                     IM1       IM1 image.  This type of image is not
                               compressed.
 
                     IO1       IOCA image.  This type of image is not
                               compressed.
 
                     IO1_MMR   Compressed IOCA image in Modified Modified
                               Read (MMR) format.

                     PSEG_IO1_G4 | PSEG_IM1 | PSEG_IO1 | PSEG_IO1_MMR
                               Page Segment of the specified image type.
                               NOTE: when generating Page Segments from
                               multiple page documents, you may wish to
                               use the -p flag (see below) to select which
                               page is to be made into a Page Segment,
                               otherwise multiple page segments will be
                               created, one for each page of PostScript.

                     OVLY_IO1_G4 | OVLY_IM1 | OVLY_IO1 | OVLY_IO1_MMR
                               Overlay of the specified image type.
                               NOTE: when generating Overlays from
                               multiple page documents, you may wish to
                               use the -p flag (see below) to select which
                               page is to be made into an Overlay,
                               otherwise multiple Overlays will be
                               created, one for each page of PostScript.
 
                     NOTE:  Printers that accept PPDS and PCL output can
                     print IOCA images; however, only channel-attached
                     printers that have the Advanced Function Image and
                     Graphics (AFIG) feature installed can print IOCA
                     images.  Therefore, if you are printing images on
                     channel-attached printers without the AFIG feature,
                     select the IM1 or IO1 value.

   -c                Concatenate multiple input files as if they are
                     just one PostScript job.  Normally, multiple input
                     files are treated as separate PostScript jobs with
                     the output of each job concatenated into one AFP
                     output file.  This flag causes the concatenation
                     to occur at the input side instead of the output
                     side.

   -C Configurationfile
                     Specifies the name of a customized configuration
                     file ps2afp uses with the transform.
 
   -F Fontmapfile(s) Specifies the file name ps2afp uses for the font
                     mapping file.  This file correlates PostScript font
                     names with their file locations.  A font mapping
                     file must exist on the RISC System/6000 where the
                     ps2afpd daemon is running (specified by the -S
                     parameter).
 
                     You can include multiple values with the -F flag by
                     separating each value with a colon (:), and the
                     files will be concatenated.  When you specify
                     multiple -F flags, ps2afp concatenates them from
                     left-to-right (first entered to last entered) in
                     that order.
 
                     If you do not specify this flag, ps2afp uses the
                     default font mapping file,
                     /usr/lpp/psf/ps2afp/ibmcore.fon.  Values are:
 
                     Fontmapfile       Any font mapping file name
 
                     NOTE:  You use the mkfntmap command to create
                     alternative font mapping files.
 
   Inputfiles        Specifies the input file name or names to be
                     transformed.  If you specify more than one input
                     file name, the ps2afp command concatenates them and
                     writes the results of the transform to a single
                     output file (if one is specified) or standard
                     output.  If you specify multiple PostScript jobs as
                     input files, the ps2afp command concatenates them
                     and separates the jobs with the Ctrl-D character.
 
                     In addition, you can specify PostScript inline
                     resource files in a PostScript header setup prolog
                     file as input files to the ps2afp command.  The file
                     name of the PostScript header setup prolog file must
                     precede the file name of the PostScript print file
                     so that ps2afp concatenates the files in the
                     correct order.  The ps2afp command concatenates the
                     resources or the prolog file in front of the print
                     file.
 
                     If you do not specify an input file, ps2afp uses
                     standard input.  If the ps2afp command cannot read
                     from standard input, ps2afp issues a message.
 
   -j [ 20 | 1 to 9998 | 9999]
                     Specifies the maximum amount of time, in minutes, to
                     spend processing the job.  Values are:
 
                     20          20 minutes
 
                     1 to 9998   The timer ranges from 1 to 9998 minutes
                                 in 1 minute increments
 
                     9999        No time limit
 
   -l nnnn.nnnu      Specifies the length of the generated image where
                     nnnn.nnn is the value and u is the units in inches
                     ("i") or millimeters ("m").  If you do not specify a
                     unit ("i" or "m"), then ps2afp uses pels as the
                     unit type.  You cannot specify fractional pel
                     values.
 
                     NOTE:  If you are using the ps2afp command to
                     transform files formatted by TeX or ditroff, set the
                     length to 11 inches (entered as -l11i) to
                     accommodate the text margin that may already be
                     built in the file.
 
                     Values are:
 
                     10.28i            10.28 inches
 
                     16 to 4080        For 240-pel resolution, the size
                                       ranges from 16 to 4080, 0.065i to
                                       17.002i, or 1.641m to 431.852m.
 
                     16 to 5100        For 300-pel resolution, the size
                                       ranges from 16 to 5100, 0.052i to
                                       17.001i, or 1.313m to 431.842m.
 
   -M [ 6000 | 2000 to nnnnn]
                     Determines the maximum amount of memory, in Kbytes,
                     that the transform can use.  Values are:
 
                     6000           6000K bytes (6M bytes)
 
                     2000 to nnnnn  The maximum memory ranges from 2000
                                    to nnnnn (where nnnnn is the maximum
                                    upper limit allowed by AIX Version
                                    3.2.2) up to 64000K bytes.
 
   -o Outputfile     Specifies the name of the output file for the
                     transform.
 
                     Outputfile     Specifies the output file into which
                                    the ps2afp command writes the
                                    transformed PostScript files.  If you
                                    specify more than one output file,
                                    the command uses the last specified
                                    file name and path.  If you do not
                                    specify an output file, the ps2afp
                                    command writes the results to
                                    standard output.

   -p nnnnn          Specifies that the output is only to contain
                     selected pages.  For example, to only output the
                     even pages, enter -p even.  To output only the
                     odd pages, enter -p odd.  To output just page
                     1, enter -p 1.  To output pages 1 through 10,
                     enter -p 1-10.  To output pages 10 through the
                     end of the job, enter -p 10-.

                     When you specify multiple -p flags, ps2afp
                     accumulates them from left-to-right (first
                     entered to last entered) in that order.

   -P [8251 | 924 to nnnnn]
                     Specifies the TCP/IP port number ps2afp uses to
                     make a connection with the workstation on which the
                     ps2afpd daemon is running (set by the -S flag).
                     Values are:
 
                     8251           The default port number.
 
                     924 to nnnnn   Any valid port number greater than or
                                    equal to 924.  To find out which
                                    ports are registered for use on your
                                    system, look in the file
                                    /etc/services.  The maximum nnnnn
                                    value is dependent on your
                                    workstation, but it must be equal to
                                    or less than 65535.
 
                     NOTE:  You can only access the secure ports, 924 to
                     1023, with root authority.
 
   -q                Quiets (suppresses) the echoing of the ps2afp
                     command to the display.
 
   -r [ 240 | 300]
                     Specifies the resolution of the output image.
                     Select the resolution based on the printer on which
                     you will be printing the image.  Valid values are:
 
                     240       240 pels-per-inch (channel-attached
                               printers)
                     300       300 pels-per-inch (PPDS and PCL printers)
 
                     NOTE:  If you specify a resolution that the printer
                     does not support, PSF/6000 will print the image
                     under most conditions, but with degraded results.
                     Specify the correct resolution for the printer on
                     which you will print the PostScript job.
 
   -S Servername     Specifies the name of the RISC System/6000 on which
                     the ps2afpd daemon is running.  If you do not
                     specify this flag, the Servername defaults to the
                     effective name of the workstation on which the you
                     issued the ps2afpd command.  Values are:
 
                     Servername     Any valid AIX workstation name on
                                    which the ps2afpd daemon is
                                    installed.
 
   -s [ 20 | 1 to 9998 | 9999]
                     Specifies the maximum amount of time, in minutes,
                     that the PostScript interpreter remains idle between
                     jobs before it goes down.  When the PostScript
                     interpreter is up and running, it uses some of the
                     workstation memory.  If the PostScript interpreter
                     goes down, you don't need to bring it back up; the
                     interpreter starts again when you submit another
                     PostScript job as long as the ps2afpd daemon is
                     running.  Values are:
 
                     20          The default time is 20 minutes.
 
                     1 to 9998   The time is the number of minutes
                                 specified in one minute increments.
 
                     9999        There is no time limit.
 
   -V [ 30 | 10 to 50]
                     Determines the maximum amount of virtual memory that
                     the transform can use as a percentage of the maximum
                     memory available, specified as an integer.  Values
                     are:
 
                     30        The default virtual memory is 30 percent
                               of the amount you specify with the -M
                               (Maxmemory) flag.
 
                     10 to 50  The virtual memory ranges from 10 to 50
                               percent of the value you specify with the
                               -M (Maxmemory) flag.
 
   -w nnnn.nnnu      Specifies the width of the generated image where
                     nnnn.nnn is the value and u is the units in inches
                     ("i") or millimeters ("m").  If you do not specify a
                     unit ("i" or "m"), then ps2afp uses a unit type of
                     pels.  You cannot specify fractional values for
                     pels.
 
                     NOTE:  If you are using the ps2afp command to
                     transform files formatted by TeX or ditroff, set the
                     width to 8.5 inches (entered as -l8.5i) to
                     accommodate the text margin that may already be
                     built in the file.
 
                     Values are:
 
                     7.78I      7.78 inches wide
 
                     16 to 3360 For 240-pel resolution, the size ranges
                                from 16 to 3360, 0.065i to 14.002i, or
                                1.641m to 355.652m.
 
                     16 to 4200 For 300-pel resolution, the size ranges
                                from 16 to 4200, 0.052i to 14.001i, or
                                1.313m to 355.642m.

   -x nnnn.nnnu      Specifies an X offset of the generated image where
                     nnnn.nnn is the value and u is the units in inches
                     ("i") or millimeters ("m").  If you do not specify a
                     unit ("i" or "m"), then ps2afp uses a unit type of
                     pels.  You cannot specify fractional values for
                     pels.  The default offset value is 0.

                     An offset value specifies a border or margin around
                     the generated image to avoid non-printable areas
                     that some printers have.  An X offset specifies the
                     left and right margins of the generated image.

   -y nnnn.nnnu      Specifies a Y offset of the generated image where
                     nnnn.nnn is the value and u is the units in inches
                     ("i") or millimeters ("m").  If you do not specify a
                     unit ("i" or "m"), then ps2afp uses a unit type of
                     pels.  You cannot specify fractional values for
                     pels.  The default offset value is 0.

                     An offset value specifies a border or margin around
                     the generated image to avoid non-printable areas
                     that some printers have.  A Y offset specifies the
                     top and bottom margins of the generated image.
 
 
Examples
 
   1.  To submit the sample PostScript file "sample.ps" supplied with
       PSF/6000 to the PSF/6000 queue named "3827P", enter:
 
         enq -P3827P -odatat=ps /usr/lpp/psf/ps2afp/sample.ps
 
   2.  To transform the PostScript file "myfile" into an AFP data stream,
       and then enqueue it for printing on the PSF/6000 queue called
       "4019", enter:
 
         ps2afp -r300 myfile | enq -P 4019
 
       NOTE:  Specify a resolution of 300 pels (-r300) because the 4019
       is a 300-pel resolution printer and the default resolution for the
       ps2afp command is 240 pels.
 
   3.  To transform the PostScript file "myfile" into an AFP data stream,
       with an image that is 8 inches high and 5 inches wide, and write
       the results to a file called "myfile.afp", enter:
 
         ps2afp -l 8i -w 5i myfile > myfile.afp
 
   4.  To transform the PostScript file "myfile" into an AFP data stream,
       with virtual memory using only 25 percent of the default memory,
       creating a compressed IO (IOCA) image (the default image type for
       the ps2afp command, and piping the result to the enq command to
       enqueue the file on the PSF/6000 queue called "3827P", enter:
 
         ps2afp -V 25 myfile | enq -P3827P
 
   5.  To transform the PostScript "myfile" file into an AFP data stream
       in 300-pel resolution, as an I01_MMR image, and send the result to
       the printer with the enq command, enter:
 
         ps2afp -aIO1_MMR -r300 myfile | enq -P4019
 
 
Implementation Specifics
 
   This command is supplied with PSF/2, and it is in the \psf2\system and 
   psf2\samples directories. To use it, TCP/IP must be installed on the system
   and the PC must have an IP address, i.e., 9.99.12.156, allocated to it. The 
   ps2afp command uses sockets, which are not part of the OS/2 operating system
   but are part of TCP/IP. The ps2afpd daemon must first be started before the
   ps2afp command can be used.

   1. Edit the \psf2\samples\ps2afp.cfg file. On the line that looks like this:

         server = 127.0.0.1       # -S which server to connect... 

      Replace the "127.0.0.1" with the IP address of your PC. Copy this file to
      the root directory, i.e., c:\.

   2. Edit the \psf2\samples\ps2afpd.cfg file. On the line that looks like this:

         work_directory = c:\psf2
                                  #             directory to put work files into 

      Replace the "\psf2" with "\psf2\system". Also change any drive specifications
      as needed. Copy this file to the root directory, i.e., c:\.
   
   3. Copy preload.ps to the work directory as specified in the previous step.

   4. Copy \psf2\samples\ps2afp.exe to the \psf2\bin directory.

   5. From an OS/2 session, start the ps2afpd program by typing: 

          c:\psf2\samples\psf2afpd -C c:\psf2\samples\ps2afpd.cfg

      Note that this OS/2 session must remain open.


Files
 
   \psf2\samples\ps2afp.exe        Transform program
   \psf2\samples\ps2afpd.exe       PostScript daemon
   \psf2\bin\arcbld.exe            PostScript interpreter program
   \psf2\samples\ps2afp.cfg        PostScript ps2afp command configuration file
   \psf2\samples\ps2afpd.cfg       PostScript ps2afpd daemon configuration file
   \psf2\system\ps2afpq.ps         PostScript initialization file
   \psf2\system\ps2afp.ps          PostScript initialization file
   \psf2\system\ps2afp2.ps         PostScript initialization file
   \psf2\system\ps2afp3.ps         PostScript initialization file
   \psf2\system\ps2afpne.ps        PostScript initialization file
   \psf2\system\ps2afpeq.ps        PostScript initialization file
   \psf2\system\preload.ps         List of fonts to be preloaded
   \psf2\system\ibmcore.fon        Default font mapping file
   \psf2\system                    Work directory for PostScript transform
 
 
Related Information:
 
       \psf2\samples\ps2afp.scr
 
       ps2afpd command
 
       "PSF/2 What's New"

       "PSF/2 Online Reference"
